intentcall_core library
Classes
- AgentAdapter
- AgentEntityIndex
- AgentEntityPropertyDescriptor
- AgentEntityProvider
- AgentEntityTypeDescriptor
- AgentIntentDescriptor
- AgentInvocation
- AgentModule
- AgentModuleFromEntries
- AgentRegistry
- AgentRegistryEntry
- AgentRegistryEvent
- AgentRuntime
- EntityTypeRegistered
- EntityTypeUnregistered
- InMemoryAgentRegistry
- IntentRegistered
- IntentUnregistered
- RegisteredAgentIntent
- ResourceRegistration
- A resource a capability wants a host to expose.
- ResourceTemplateRegistration
- A parameterized resource template a capability wants a host to expose.
- ToolRegistration
- A tool a capability wants a host to expose.
Enums
Extension Types
Extensions
Functions
-
qualifyName(
{required String namespace, required String name}) → String -
registerAll(
AgentRegistry registry, Iterable< AgentCallEntry> entries) → void -
validateBareName(
String name) → void -
validateNamespace(
String namespace) → void
Typedefs
-
AgentCallHandler
= FutureOr<
AgentResult> Function(AgentArguments request) -
AgentExecutor
= Future<
AgentResult> Function(AgentInvocation invocation) - AgentValidator = void Function(AgentArguments arguments)
-
ResourceHandler
= Future<
AgentResult> Function(String uri) -
Handler for a capability resource read using transport-agnostic
AgentResult. -
ToolHandler
= Future<
AgentResult> Function(AgentArguments arguments) -
Handler for a capability tool using transport-agnostic
AgentResult.