MigrateAgentEntriesFileResult class final

Result of migrating one Dart file from MCPCallEntry to AgentCallEntry.

Constructors

MigrateAgentEntriesFileResult({required String path, required bool changed, required String migrated})
const

Properties

changed bool
final
hashCode int
The hash code for this object.
no setterinherited
migrated String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited