MigrateAgentEntriesReport class final
Summary of a migrate run over a file or directory.
Constructors
-
MigrateAgentEntriesReport({required int filesScanned, required int filesChanged, required List<
MigrateAgentEntriesFileResult> results}) -
const
Properties
- filesChanged → int
-
final
- filesScanned → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
→ List<
MigrateAgentEntriesFileResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wouldChange → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited